==> netease_roomkit_interface-0.0.1-rc.0.tar.gz: lib/src/method_channel/method_channel_preview_room_rtc_controller.dart <==
import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/preview_room_rtc_controller_platform.dart';
import 'package:netease_roomkit_interface/src/types/rtc_models.dart';

class MethodChannelPreviewRoomRtcController extends PreviewRoomRtcControllerPlatform {
  final _api = PreviewRoomRtcControllerApi();

  @override
  Future<VoidResult> startPreview() {
    return _api
        .startPreview()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopPreview() {
    return _api
        .stopPreview()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> switchCamera() {
    return _api
        .switchCamera()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautyFilter(String path) {
    return _api
        .addBeautyFilter(path)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautySticker(String path) {
    return _api
        .addBeautySticker(path)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableBeauty(bool isOpenBeauty) {
    return _api
        .enableBeauty(isOpenBeauty)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautyFilter() {
    return _api
        .removeBeautyFilter()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautySticker() {
    return _api
        .removeBeautySticker()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyEffect(
      NERoomBeautyEffectType beautyType, double level) {
    return _api
        .setBeautyEffect(
            NERoomBeautyEffectTypeExtension.fromType(beautyType), level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyFilterLevel(double level) {
    return _api
        .setBeautyFilterLevel(level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startBeauty() {
    return _api
        .startBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopBeauty() {
    return _api
        .stopBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

}

==> netease_roomkit_interface-1.26.0.tar.gz: lib/src/method_channel/method_channel_preview_room_rtc_controller.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'package:netease_common/netease_common.dart';
import 'package:netease_roomkit_interface/src/pigeon.dart';
import 'package:netease_roomkit_interface/src/platform_interface/preview_room_rtc_controller_platform.dart';
import 'package:netease_roomkit_interface/src/types/rtc_models.dart';

class MethodChannelPreviewRoomEventSink extends PreviewRoomEventSink {
  final Set<PreviewRoomEventSink> _listeners = <PreviewRoomEventSink>{};

  void registerEventListener(PreviewRoomEventSink listener) {
    _listeners.add(listener);
  }

  void unregisterEventListener(PreviewRoomEventSink listener) {
    _listeners.remove(listener);
  }

  @override
  void onRtcVirtualBackgroundSourceEnabled(
      RtcVirtualBackgroundSourceEvent event) {
    for (var element in _listeners) {
      element.onRtcVirtualBackgroundSourceEnabled(event);
    }
  }
}

class MethodChannelPreviewRoomRtcController
    extends PreviewRoomRtcControllerPlatform {
  final _api = PreviewRoomRtcControllerApi();
  final _eventDispatcher = MethodChannelPreviewRoomEventSink();

  MethodChannelPreviewRoomRtcController() {
    PreviewRoomEventSink.setup(_eventDispatcher);
  }

  @override
  void registerEventListener(PreviewRoomEventSink listener) {
    _eventDispatcher.registerEventListener(listener);
  }

  @override
  void unregisterEventListener(PreviewRoomEventSink listener) {
    _eventDispatcher.unregisterEventListener(listener);
  }

  @override
  Future<VoidResult> startPreview() {
    return _api
        .startPreview()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopPreview(bool releaseRtc) {
    return _api
        .stopPreview(releaseRtc)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> switchCamera() {
    return _api
        .switchCamera()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautyFilter(String path) {
    return _api
        .addBeautyFilter(path)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> addBeautySticker(String path) {
    return _api
        .addBeautySticker(path)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableBeauty(bool isOpenBeauty) {
    return _api
        .enableBeauty(isOpenBeauty)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautyFilter() {
    return _api
        .removeBeautyFilter()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> removeBeautySticker() {
    return _api
        .removeBeautySticker()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyEffect(
      NERoomBeautyEffectType beautyType, double level) {
    return _api
        .setBeautyEffect(
            NERoomBeautyEffectTypeExtension.fromType(beautyType), level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> setBeautyFilterLevel(double level) {
    return _api
        .setBeautyFilterLevel(level)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> startBeauty() {
    return _api
        .startBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> stopBeauty() {
    return _api
        .stopBeauty()
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }

  @override
  Future<VoidResult> enableVirtualBackground(
      bool enabled, NERoomVirtualBackgroundSource backgroundSource) {
    return _api
        .enableVirtualBackground(enabled, backgroundSource)
        .then((value) => VoidResult(code: value.code, msg: value.msg));
  }
}
